@@ -2,21 +2,22 @@ context("fCover")
 
 
 suppressPackageStartupMessages(library(raster))
-suppressPackageStartupMessages(library(randomForest))
 
 data(lsat)
-lc	  <- unsuperClass(lsat, nClass=3)$map
+lc	  <- unsuperClass(lsat, nSamples = 50, nClass=3)$map
 modis <- aggregate(lsat, 9)
 
 
 for(cl in 1:2) {
+    if (!identical(Sys.getenv("NOT_CRAN"), "true") && cl == 2) next
+    
 	test_that(sprintf("works for %s classes(s)",cl), {
 				expect_is(fc <- fCover(
 								classImage = lc ,
 								predImage = modis,
 								classes=1:cl,
-								model="rf",
-								nSample = 50,
+								model="lm",
+								nSample = 30,
 								number = 5,
 								tuneLength=1
 						), c("RStoolbox", "fCover"))
